==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/utils/canBeRemoved.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/utils/canBeRemoved", ['module', 'exports', 'require', '../components/layout-data-items/hasDropZoneChild', '../config/constants/layoutDataItemTypes'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = canBeRemoved;

    var _hasDropZoneChild = _interopRequireDefault(require("../components/layout-data-items/hasDropZoneChild"));

    var _layoutDataItemTypes = require("../config/constants/layoutDataItemTypes");

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function canBeRemoved(item, layoutData) {
      switch (item.type) {
        case _layoutDataItemTypes.LAYOUT_DATA_ITEM_TYPES.column:
        case _layoutDataItemTypes.LAYOUT_DATA_ITEM_TYPES.dropZone:
          return false;

        default:
          return !(0, _hasDropZoneChild["default"])(item, layoutData);
      }
    }
    //# sourceMappingURL=canBeRemoved.js.map
  }
});
//# sourceMappingURL=canBeRemoved.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/utils/canBeRemoved.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/utils/canBeRemoved", ['module', 'exports', 'require', '../components/layout-data-items/hasDropZoneChild', '../config/constants/layoutDataItemTypes'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = canBeRemoved;

    var _hasDropZoneChild = _interopRequireDefault(require("../components/layout-data-items/hasDropZoneChild"));

    var _layoutDataItemTypes = require("../config/constants/layoutDataItemTypes");

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function canBeRemoved(item, layoutData) {
      switch (item.type) {
        case _layoutDataItemTypes.LAYOUT_DATA_ITEM_TYPES.column:
        case _layoutDataItemTypes.LAYOUT_DATA_ITEM_TYPES.dropZone:
          return false;

        default:
          return !(0, _hasDropZoneChild.default)(item, layoutData);
      }
    }
    //# sourceMappingURL=canBeRemoved.js.map
  }
});
//# sourceMappingURL=canBeRemoved.js.map
